Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2610)

Unified Diff: media/audio/audio_output_controller.h

Issue 2517503003: Reland: Make more media APIs aware of |delay| and |delay_timestamp| (Closed)
Patch Set: Comments from chcunningham@ and Dale Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/renderer/media/webrtc_audio_renderer.cc ('k') | media/audio/audio_output_controller.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/audio/audio_output_controller.h
diff --git a/media/audio/audio_output_controller.h b/media/audio/audio_output_controller.h
index 856716f7774f943f9342b1c951d53eef6fce6091..ce16c1d16336e3207ec37201a083bf14d20e3a2e 100644
--- a/media/audio/audio_output_controller.h
+++ b/media/audio/audio_output_controller.h
@@ -88,14 +88,14 @@ class MEDIA_EXPORT AudioOutputController
public:
virtual ~SyncReader() {}
- // Notify the synchronous reader the number of bytes in the
- // AudioOutputController not yet played. This is used by SyncReader to
- // prepare more data and perform synchronization. Also inform about if any
- // frames has been skipped by the renderer (typically the OS). The renderer
- // source can handle this appropriately depending on the type of source. An
- // ordinary file playout would ignore this.
- virtual void UpdatePendingBytes(uint32_t bytes,
- uint32_t frames_skipped) = 0;
+ // This is used by SyncReader to prepare more data and perform
+ // synchronization. Also inform about output delay at a certain moment and
+ // if any frames have been skipped by the renderer (typically the OS). The
+ // renderer source can handle this appropriately depending on the type of
+ // source. An ordinary file playout would ignore this.
+ virtual void RequestMoreData(base::TimeDelta delay,
+ base::TimeTicks delay_timestamp,
+ int prior_frames_skipped) = 0;
// Attempts to completely fill |dest|, zeroing |dest| if the request can not
// be fulfilled (due to timeout).
« no previous file with comments | « content/renderer/media/webrtc_audio_renderer.cc ('k') | media/audio/audio_output_controller.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698